@@ -1,17 +1,21 @@
-# Copyrights 2009-2017 by [Mark Overmeer].
+# Copyrights 2009-2018 by [Mark Overmeer <markov@cpan.org>].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.02.
-use warnings;
-use strict;
+# This code is part of distribution XML-Compile-SOAP12.  Meta-POD processed
+# with OODoc into POD and HTML manual-pages.  See README.md
+# Copyright Mark Overmeer.  Licensed under the same terms as Perl itself.
 
 package XML::Compile::SOAP12::Client;
 use vars '$VERSION';
-$VERSION = '3.05';
+$VERSION = '3.06';
 
 use base 'XML::Compile::SOAP12', 'XML::Compile::SOAP::Client';
 
-use Log::Report 'xml-compile-soap12', syntax => 'SHORT';
+use warnings;
+use strict;
+
+use Log::Report 'xml-compile-soap12';
 
 
 # much work to do ;-)
